@@ -393,7 +393,7 @@ class RundeckJobs(object):
                                            pg_password=pg_creds['password'],
                                            pg_ip=pg_creds['ip'],
                                            pg_port=pg_creds['port'],
-                                           pg_db=pg_creds['dbname'],
+                                           pg_db=pg_creds['db_name'],
                                            fqdn=fqdn, organization=organization,
                                            datacenter=datacenter,
                                            tag_names=os.environ.get(
